Skip to contents

A small contiguous subset of NYC census tracts for examples and testing.

Usage

nyc_ct_small

Format

An sf object with the same columns as nyc_ct.

American Community Survey 2023; LEHD LODES 2022. This product uses Census Bureau data but is not endorsed or certified by the Census Bureau.