R/nyc_data.R
nyc_ct_small.Rd
A small contiguous subset of NYC census tracts for examples and testing.
nyc_ct_small
An sf object with the same columns as nyc_ct.
nyc_ct
American Community Survey 2023; LEHD LODES 2022. This product uses Census Bureau data but is not endorsed or certified by the Census Bureau.