Provides tools for pycnophylactic interpolation of polygon totals to discrete global and local grid systems. The method follows Tobler (1979) doi:10.1080/01621459.1979.10481647 , preserving source-zone totals while smoothing values across neighboring target cells.
Author
Maintainer: Christopher Higgins cd.higgins@utoronto.ca [copyright holder]
Authors:
Christopher Higgins cd.higgins@utoronto.ca [copyright holder]